
# pescea - python interface to Escea fireplaces

This is a python interface to the [Escea range](https://escea.com/) of fireplaces.

The specifications for the interface are contained in the [included pdf](./630260_3_Escea_Fireplace_LAN_Comms_Spec.pdf).

Further information on the Escea controller's network communications can be found in [this pdf](./Escea_Controller_Network_Communications_Summary.pdf)

Note: The above documents are copyright of Escea

## Usage

This package is not a standalone application for end user implementation.

The aim of this package is to be used by software developers and integrators to implement
the Escea interface on home automation platforms.

## Credit

The [pizone interface](https://github.com/Swamp-Ig/pizone) was used as a template and
for inspiration in developing this interface (which saved a lot of time, so thanks!)
